@@ -1,18 +1,18 @@
 
 --- Module implementing the LuaRocks "doc" command.
 -- Shows documentation for an installed rock.
---module("luarocks.doc", package.seeall)
 local doc = {}
 package.loaded["luarocks.doc"] = doc
 
 local util = require("luarocks.util")
-local show = require("luarocks.show")
+local search = require("luarocks.search")
 local path = require("luarocks.path")
 local dir = require("luarocks.dir")
 local fetch = require("luarocks.fetch")
 local fs = require("luarocks.fs")
 local download = require("luarocks.download")
 
+util.add_run_function(doc)
 doc.help_summary = "Show documentation for an installed rock."
 
 doc.help = [[
@@ -58,13 +58,14 @@ end
 -- @param name or nil: an existing package name.
 -- @param version string or nil: a version may also be passed.
 -- @return boolean: True if succeeded, nil on errors.
-function doc.run(...)
-   local flags, name, version = util.parse_flags(...)
+function doc.command(flags, name, version)
    if not name then
       return nil, "Argument missing. "..util.see_help("doc")
    end
 
-   local iname, iversion, repo = show.pick_installed_rock(name, version, flags["tree"])
+   name = name:lower()
+
+   local iname, iversion, repo = search.pick_installed_rock(name, version, flags["tree"])
    if not iname then
       util.printout(name..(version and " "..version or "").." is not installed. Looking for it in the rocks servers...")
       return try_to_open_homepage(name, version)
