@@ -1,6 +1,5 @@
 
 --- Unix implementation of filesystem and platform abstractions.
---module("luarocks.fs.unix", package.seeall)
 local unix = {}
 
 local fs = require("luarocks.fs")
@@ -9,8 +8,6 @@ local cfg = require("luarocks.cfg")
 local dir = require("luarocks.dir")
 local util = require("luarocks.util")
 
-math.randomseed(os.time())
-
 --- Annotate command string for quiet execution.
 -- @param cmd string: A command-line string.
 -- @return string: The command-line, with silencing annotation.
@@ -18,6 +15,22 @@ function unix.quiet(cmd)
    return cmd.." 1> /dev/null 2> /dev/null"
 end
 
+--- Annotate command string for execution with quiet stderr.
+-- @param cmd string: A command-line string.
+-- @return string: The command-line, with stderr silencing annotation.
+function unix.quiet_stderr(cmd)
+   return cmd.." 2> /dev/null"
+end
+
+--- Quote argument for shell processing.
+-- Adds single quotes and escapes.
+-- @param arg string: Unquoted argument.
+-- @return string: Quoted argument.
+function unix.Q(arg)
+   assert(type(arg) == "string")
+   return "'" .. arg:gsub("'", "'\\''") .. "'"
+end
+
 --- Return an absolute pathname from a potentially relative one.
 -- @param pathname string: pathname to convert.
 -- @param relative_to string or nil: path to prepend when making
@@ -68,7 +81,7 @@ function unix.wrap_script(file, dest, name, version)
    local addctx = "local k,l,_=pcall(require,"..util.LQ("luarocks.loader")..") _=k and l.add_context("..util.LQ(name)..","..util.LQ(version)..")"
    wrapper:write('exec '..fs.Q(lua)..' -e '..fs.Q(ppaths)..' -e '..fs.Q(addctx)..' '..fs.Q(file)..' "$@"\n')
    wrapper:close()
-   if fs.chmod(wrapname, "0755") then
+   if fs.chmod(wrapname, cfg.perm_exec) then
       return true
    else
       return nil, "Could not make "..wrapname.." executable."
@@ -98,7 +111,7 @@ function unix.is_actual_binary(filename)
 end
 
 function unix.copy_binary(filename, dest) 
-   return fs.copy(filename, dest, "0755")
+   return fs.copy(filename, dest, cfg.perm_exec)
 end
 
 --- Move a file on top of the other.
@@ -119,4 +132,8 @@ function unix.tmpname()
    return os.tmpname()
 end
 
+function unix.current_user()
+   return os.getenv("USER")
+end
+
 return unix
